powered by
Create histograms for all numeric variables in a dataset. Non-numeric variables will be dropped.
gghist(d, cols, bins = 30, nsub = TRUE, ...)
A ggplot object.
<dfr> A data frame.
<dfr>
<var> Optional. Columns to plot as a vector of unquoted names.
<var>
<int> Number of bins.
<int>
<lgl> Show number of observations.
<lgl>
Additional arguments for ggplot2::geom_histogram.
iris |> gghist() iris |> gghist(c(Sepal.Width,Sepal.Length))
Run the code above in your browser using DataLab